@@ -462,6 +462,8 @@
 #define PCI_CHIP_CYPRESS_6888 0x6888
 #define PCI_CHIP_CYPRESS_6889 0x6889
 #define PCI_CHIP_CYPRESS_688A 0x688A
+#define PCI_CHIP_CYPRESS_688C 0x688C
+#define PCI_CHIP_CYPRESS_688D 0x688D
 #define PCI_CHIP_CYPRESS_6898 0x6898
 #define PCI_CHIP_CYPRESS_6899 0x6899
 #define PCI_CHIP_CYPRESS_689E 0x689E
@@ -491,6 +493,7 @@
 #define PCI_CHIP_CEDAR_68E8 0x68E8
 #define PCI_CHIP_CEDAR_68E9 0x68E9
 #define PCI_CHIP_CEDAR_68F1 0x68F1
+#define PCI_CHIP_CEDAR_68F2 0x68F2
 #define PCI_CHIP_CEDAR_68F8 0x68F8
 #define PCI_CHIP_CEDAR_68F9 0x68F9
 #define PCI_CHIP_CEDAR_68FE 0x68FE
