@@ -46,7 +46,7 @@
 struct blendinfo {
 	Bool dst_alpha;
 	Bool src_alpha;
-	CARD32 blend_cntl;
+	uint32_t blend_cntl;
 };
 
 /* The first part of blend_cntl corresponds to Fa from the render "protocol"
@@ -166,8 +166,8 @@ static CARD32 RADEONDstFormats[] = {
     0
 };
 
-static CARD32
-RadeonGetTextureFormat(CARD32 format)
+static uint32_t
+RadeonGetTextureFormat(uint32_t format)
 {
     switch (format) {
     case PICT_a8r8g8b8:
@@ -187,8 +187,8 @@ RadeonGetTextureFormat(CARD32 format)
     }
 }
 
-static CARD32
-RadeonGetColorFormat(CARD32 format)
+static uint32_t
+RadeonGetColorFormat(uint32_t format)
 {
     switch (format) {
     case PICT_a8r8g8b8:
@@ -207,10 +207,10 @@ RadeonGetColorFormat(CARD32 format)
 /* Returns a RADEON_RB3D_BLENDCNTL value, or 0 if the operation is not
  * supported
  */
-static CARD32
-RadeonGetBlendCntl(CARD8 op, CARD32 dstFormat)
+static uint32_t
+RadeonGetBlendCntl(uint8_t op, uint32_t dstFormat)
 {
-    CARD32 blend_cntl;
+    uint32_t blend_cntl;
 
     if (op >= RadeonOpMax || RadeonBlendOp[op].blend_cntl == 0)
 	return 0;
@@ -218,7 +218,7 @@ RadeonGetBlendCntl(CARD8 op, CARD32 dstFormat)
     blend_cntl = RadeonBlendOp[op].blend_cntl;
 	
     if (RadeonBlendOp[op].dst_alpha && !PICT_FORMAT_A(dstFormat)) {
-	CARD32 srcblend = blend_cntl & RADEON_SRC_BLEND_MASK;
+	uint32_t srcblend = blend_cntl & RADEON_SRC_BLEND_MASK;
 
 	/* If there's no destination alpha channel, we need to wire the blending
 	 * to treat the alpha channel as always 1.
@@ -235,11 +235,11 @@ RadeonGetBlendCntl(CARD8 op, CARD32 dstFormat)
     return blend_cntl;
 }
 
-static __inline__ CARD32 F_TO_DW(float val)
+static __inline__ uint32_t F_TO_DW(float val)
 {
     union {
 	float f;
-	CARD32 l;
+	uint32_t l;
     } tmp;
     tmp.f = val;
     return tmp.l;
@@ -250,10 +250,17 @@ static __inline__ int
 ATILog2(int val)
 {
 	int bits;
-
+#if (defined __i386__ || defined __x86_64__) && (defined __GNUC__)
+	__asm volatile("bsrl	%1, %0"
+		: "=r" (bits)
+		: "c" (val)
+	);
+	return bits;
+#else
 	for (bits = 0; val != 0; val >>= 1, ++bits)
 		;
 	return bits - 1;
+#endif
 }
 
 static void
@@ -261,7 +268,7 @@ RemoveLinear (FBLinearPtr linear)
 {
    RADEONInfoPtr info = (RADEONInfoPtr)(linear->devPrivate.ptr);
 
-   info->RenderTex = NULL; 
+   info->accel_state->RenderTex = NULL; 
 }
 
 static void
@@ -269,13 +276,14 @@ RenderCallback (ScrnInfoPtr pScrn)
 {
     RADEONInfoPtr  info       = RADEONPTR(pScrn);
 
-    if ((currentTime.milliseconds > info->RenderTimeout) && info->RenderTex) {
-	xf86FreeOffscreenLinear(info->RenderTex);
-	info->RenderTex = NULL;
+    if ((currentTime.milliseconds > info->accel_state->RenderTimeout) &&
+	info->accel_state->RenderTex) {
+	xf86FreeOffscreenLinear(info->accel_state->RenderTex);
+	info->accel_state->RenderTex = NULL;
     }
 
-    if (!info->RenderTex)
-	info->RenderCallback = NULL;
+    if (!info->accel_state->RenderTex)
+	info->accel_state->RenderCallback = NULL;
 }
 
 static Bool
@@ -286,30 +294,30 @@ AllocateLinear (
    RADEONInfoPtr  info       = RADEONPTR(pScrn);
    int cpp = info->CurrentLayout.bitsPerPixel / 8;
 
-   info->RenderTimeout = currentTime.milliseconds + 30000;
-   info->RenderCallback = RenderCallback;
+   info->accel_state->RenderTimeout = currentTime.milliseconds + 30000;
+   info->accel_state->RenderCallback = RenderCallback;
 
    /* XAA allocates in units of pixels at the screen bpp, so adjust size
     * appropriately.
     */
    sizeNeeded = (sizeNeeded + cpp - 1) / cpp;
 
-   if (info->RenderTex) {
-	if (info->RenderTex->size >= sizeNeeded)
+   if (info->accel_state->RenderTex) {
+	if (info->accel_state->RenderTex->size >= sizeNeeded)
 	   return TRUE;
 	else {
-	   if (xf86ResizeOffscreenLinear(info->RenderTex, sizeNeeded))
+	   if (xf86ResizeOffscreenLinear(info->accel_state->RenderTex, sizeNeeded))
 		return TRUE;
 
-	   xf86FreeOffscreenLinear(info->RenderTex);
-	   info->RenderTex = NULL;
+	   xf86FreeOffscreenLinear(info->accel_state->RenderTex);
+	   info->accel_state->RenderTex = NULL;
 	}
    }
 
-   info->RenderTex = xf86AllocateOffscreenLinear(pScrn->pScreen, sizeNeeded, 32,
-						 NULL, RemoveLinear, info);
+   info->accel_state->RenderTex = xf86AllocateOffscreenLinear(pScrn->pScreen, sizeNeeded, 32,
+							      NULL, RemoveLinear, info);
 
-   return (info->RenderTex != NULL);
+   return (info->accel_state->RenderTex != NULL);
 }
 
 #if X_BYTE_ORDER == X_BIG_ENDIAN
@@ -317,7 +325,7 @@ static Bool RADEONSetupRenderByteswap(ScrnInfoPtr pScrn, int tex_bytepp)
 {
     RADEONInfoPtr info = RADEONPTR(pScrn);
     unsigned char *RADEONMMIO = info->MMIO;
-    CARD32 swapper = info->ModeReg.surface_cntl;
+    uint32_t swapper = info->ModeReg->surface_cntl;
 
     swapper &= ~(RADEON_NONSURF_AP0_SWP_16BPP | RADEON_NONSURF_AP1_SWP_16BPP |
 		 RADEON_NONSURF_AP0_SWP_32BPP | RADEON_NONSURF_AP1_SWP_32BPP);
@@ -345,7 +353,7 @@ static void RADEONRestoreByteswap(RADEONInfoPtr info)
 {
     unsigned char *RADEONMMIO = info->MMIO;
 
-    OUTREG(RADEON_SURFACE_CNTL, info->ModeReg.surface_cntl);
+    OUTREG(RADEON_SURFACE_CNTL, info->ModeReg->surface_cntl);
 }
 #endif	/* X_BYTE_ORDER == X_BIG_ENDIAN */
 
@@ -373,22 +381,22 @@ static void RADEONRestoreByteswap(RADEONInfoPtr info)
 
 static Bool FUNC_NAME(R100SetupTexture)(
 	ScrnInfoPtr pScrn,
-	CARD32 format,
-	CARD8 *src,
+	uint32_t format,
+	uint8_t *src,
 	int src_pitch,
 	unsigned int width,
 	unsigned int height,
 	int flags)
 {
     RADEONInfoPtr info = RADEONPTR(pScrn);
-    CARD8 *dst;
-    CARD32 tex_size = 0, txformat;
+    uint8_t *dst;
+    uint32_t tex_size = 0, txformat;
     int dst_pitch, offset, size, tex_bytepp;
 #ifdef ACCEL_CP
-    CARD32 buf_pitch, dst_pitch_off;
+    uint32_t buf_pitch, dst_pitch_off;
     int x, y;
     unsigned int hpass;
-    CARD8 *tmp_dst;
+    uint8_t *tmp_dst;
 #endif
     ACCEL_PREAMBLE();
 
@@ -398,11 +406,11 @@ static Bool FUNC_NAME(R100SetupTexture)(
     txformat = RadeonGetTextureFormat(format);
     tex_bytepp = PICT_FORMAT_BPP(format) >> 3;
 
-    dst_pitch = (width * tex_bytepp + 63) & ~63;
+    dst_pitch = RADEON_ALIGN(width * tex_bytepp, 64);
     size = dst_pitch * height;
 
     if ((flags & XAA_RENDER_REPEAT) && (height != 1) &&
-	(((width * tex_bytepp + 31) & ~31) != dst_pitch))
+	(RADEON_ALIGN(width * tex_bytepp, 32) != dst_pitch))
 	return FALSE;
 
 #ifndef ACCEL_CP
@@ -428,8 +436,8 @@ static Bool FUNC_NAME(R100SetupTexture)(
 	txformat |= RADEON_TXFORMAT_NON_POWER2;
     }
 
-    offset = info->RenderTex->offset * pScrn->bitsPerPixel / 8;
-    dst = (CARD8*)(info->FB + offset);
+    offset = info->accel_state->RenderTex->offset * pScrn->bitsPerPixel / 8;
+    dst = (uint8_t*)(info->FB + offset);
 
     /* Upload texture to card. */
 
@@ -452,8 +460,8 @@ static Bool FUNC_NAME(R100SetupTexture)(
 
 #else
 
-    if (info->accel->NeedToSync)
-	info->accel->Sync(pScrn);
+    if (info->accel_state->accel->NeedToSync)
+	info->accel_state->accel->Sync(pScrn);
 
     while (height--) {
 	memcpy(dst, src, width * tex_bytepp);
@@ -500,14 +508,14 @@ FUNC_NAME(R100SetupForCPUToScreenAlphaTexture) (
 ) 
 {
     RADEONInfoPtr info = RADEONPTR(pScrn);
-    CARD32 colorformat, srccolor, blend_cntl;
+    uint32_t colorformat, srccolor, blend_cntl;
     ACCEL_PREAMBLE();
 
     blend_cntl = RadeonGetBlendCntl(op, dstFormat);
     if (blend_cntl == 0)
 	return FALSE;
 
-    if (!info->XInited3D)
+    if (!info->accel_state->XInited3D)
 	RADEONInit3DEngine(pScrn);
 
     if (!FUNC_NAME(R100SetupTexture)(pScrn, maskFormat, alphaPtr, alphaPitch,
@@ -551,14 +559,14 @@ FUNC_NAME(R100SetupForCPUToScreenTexture) (
 )
 {
     RADEONInfoPtr info = RADEONPTR(pScrn);
-    CARD32 colorformat, blend_cntl;
+    uint32_t colorformat, blend_cntl;
     ACCEL_PREAMBLE();
 
     blend_cntl = RadeonGetBlendCntl(op, dstFormat);
     if (blend_cntl == 0)
 	return FALSE;
     
-    if (!info->XInited3D)
+    if (!info->accel_state->XInited3D)
 	RADEONInit3DEngine(pScrn);
 
     if (!FUNC_NAME(R100SetupTexture)(pScrn, srcFormat, texPtr, texPitch, width,
@@ -598,7 +606,7 @@ FUNC_NAME(R100SubsequentCPUToScreenTexture) (
 {
     RADEONInfoPtr  info       = RADEONPTR(pScrn);
     int byteshift;
-    CARD32 fboffset;
+    uint32_t fboffset;
     float l, t, r, b, fl, fr, ft, fb;
 
     ACCEL_PREAMBLE();
@@ -710,22 +718,22 @@ FUNC_NAME(R100SubsequentCPUToScreenTexture) (
 
 static Bool FUNC_NAME(R200SetupTexture)(
 	ScrnInfoPtr pScrn,
-	CARD32 format,
-	CARD8 *src,
+	uint32_t format,
+	uint8_t *src,
 	int src_pitch,
 	unsigned int width,
 	unsigned int height,
 	int flags)
 {
     RADEONInfoPtr info = RADEONPTR(pScrn);
-    CARD8 *dst;
-    CARD32 tex_size = 0, txformat;
+    uint8_t *dst;
+    uint32_t tex_size = 0, txformat;
     int dst_pitch, offset, size, tex_bytepp;
 #ifdef ACCEL_CP
-    CARD32 buf_pitch, dst_pitch_off;
+    uint32_t buf_pitch, dst_pitch_off;
     int x, y;
     unsigned int hpass;
-    CARD8 *tmp_dst;
+    uint8_t *tmp_dst;
 #endif
     ACCEL_PREAMBLE();
 
@@ -735,11 +743,11 @@ static Bool FUNC_NAME(R200SetupTexture)(
     txformat = RadeonGetTextureFormat(format);
     tex_bytepp = PICT_FORMAT_BPP(format) >> 3;
 
-    dst_pitch = (width * tex_bytepp + 63) & ~63;
+    dst_pitch = RADEON_ALIGN(width * tex_bytepp, 64);
     size = dst_pitch * height;
 
     if ((flags & XAA_RENDER_REPEAT) && (height != 1) &&
-	(((width * tex_bytepp + 31) & ~31) != dst_pitch))
+	(RADEON_ALIGN(width * tex_bytepp, 32) != dst_pitch))
 	return FALSE;
 
 #ifndef ACCEL_CP
@@ -765,11 +773,11 @@ static Bool FUNC_NAME(R200SetupTexture)(
 	txformat |= RADEON_TXFORMAT_NON_POWER2;
     }
 
-    info->texW[0] = width;
-    info->texH[0] = height;
+    info->accel_state->texW[0] = width;
+    info->accel_state->texH[0] = height;
 
-    offset = info->RenderTex->offset * pScrn->bitsPerPixel / 8;
-    dst = (CARD8*)(info->FB + offset);
+    offset = info->accel_state->RenderTex->offset * pScrn->bitsPerPixel / 8;
+    dst = (uint8_t*)(info->FB + offset);
 
     /* Upload texture to card. */
 
@@ -792,8 +800,8 @@ static Bool FUNC_NAME(R200SetupTexture)(
 
 #else
 
-    if (info->accel->NeedToSync)
-	info->accel->Sync(pScrn);
+    if (info->accel_state->accel->NeedToSync)
+	info->accel_state->accel->Sync(pScrn);
 
     while (height--) {
 	memcpy(dst, src, width * tex_bytepp);
@@ -841,14 +849,14 @@ FUNC_NAME(R200SetupForCPUToScreenAlphaTexture) (
 ) 
 {
     RADEONInfoPtr  info = RADEONPTR(pScrn);
-    CARD32 colorformat, srccolor, blend_cntl;
+    uint32_t colorformat, srccolor, blend_cntl;
     ACCEL_PREAMBLE();
 
     blend_cntl = RadeonGetBlendCntl(op, dstFormat);
     if (blend_cntl == 0)
 	return FALSE;
 
-    if (!info->XInited3D)
+    if (!info->accel_state->XInited3D)
 	RADEONInit3DEngine(pScrn);
 
     if (!FUNC_NAME(R200SetupTexture)(pScrn, maskFormat, alphaPtr, alphaPitch,
@@ -893,14 +901,14 @@ FUNC_NAME(R200SetupForCPUToScreenTexture) (
 )
 {
     RADEONInfoPtr  info       = RADEONPTR(pScrn);
-    CARD32 colorformat, blend_cntl;
+    uint32_t colorformat, blend_cntl;
     ACCEL_PREAMBLE();
 
     blend_cntl = RadeonGetBlendCntl(op, dstFormat);
     if (blend_cntl == 0)
 	return FALSE;
 
-    if (!info->XInited3D)
+    if (!info->accel_state->XInited3D)
 	RADEONInit3DEngine(pScrn);
 
     if (!FUNC_NAME(R200SetupTexture)(pScrn, srcFormat, texPtr, texPitch, width,
@@ -941,7 +949,7 @@ FUNC_NAME(R200SubsequentCPUToScreenTexture) (
 {
     RADEONInfoPtr  info       = RADEONPTR(pScrn);
     int byteshift;
-    CARD32 fboffset;
+    uint32_t fboffset;
     float l, t, r, b, fl, fr, ft, fb;
     ACCEL_PREAMBLE();
 
@@ -967,10 +975,10 @@ FUNC_NAME(R200SubsequentCPUToScreenTexture) (
     
     r = width + l;
     b = height + t;
-    fl = (float)srcx / info->texW[0];
-    fr = (float)(srcx + width) / info->texW[0];
-    ft = (float)srcy / info->texH[0];
-    fb = (float)(srcy + height) / info->texH[0];
+    fl = (float)srcx / info->accel_state->texW[0];
+    fr = (float)(srcx + width) / info->accel_state->texW[0];
+    ft = (float)srcy / info->accel_state->texH[0];
+    fb = (float)(srcy + height) / info->accel_state->texH[0];
 
 #ifdef ACCEL_CP
     BEGIN_RING(24);
